import { DeclareConstructor } from "dojo/_base/declare";
import { ExtensionEvent } from "dojo/on";
import { WatchHandle } from "dojo/interfaces";
import { A11yClick } from "./a11yclick";

interface _OnDijitClickMixin {
    /**
     * override _WidgetBase.connect() to make this.connect(node, "ondijitclick", ...) work
     */
    connect(obj: any, event: string | ExtensionEvent, method: string | EventListener): WatchHandle;
}

/**
 * Deprecated.   New code should access the dijit/a11yclick event directly, ex:
 * this.own(on(node, a11yclick, function(){ ... }));
 *
 * Mixing in this class will make _WidgetBase.connect(node, "ondijitclick", ...) work.
 * It also used to be necessary to make templates with ondijitclick work, but now you can just require
 * dijit/a11yclick.
 */
interface _OnDijitClickMixinConstructor extends DeclareConstructor<_OnDijitClickMixin>{
    a11yclick: A11yClick;
}

declare module "dojo/_base/kernel" {
    interface Dijit {
        _OnDijitClickMixin: _OnDijitClickMixinConstructor;
    }
}

declare const _OnDijitClickMixin: _OnDijitClickMixinConstructor;
export = _OnDijitClickMixin;
